pub trait IBusEngineBackend: IBusEngine + 'static {
// Required methods
fn commit_text(
se: &SignalEmitter<'_>,
text: String,
) -> impl Future<Output = Result<()>> + Send;
fn update_lookup_table(
se: &SignalEmitter<'_>,
table: &LookupTable,
visible: bool,
) -> impl Future<Output = Result<()>> + Send;
fn update_preedit_text(
se: &SignalEmitter<'_>,
text: String,
cursor_pos: u32,
visible: bool,
mode: IBusPreeditFocusMode,
) -> impl Future<Output = Result<()>> + Send;
fn update_auxiliary_text(
se: &SignalEmitter<'_>,
text: String,
visible: bool,
) -> impl Future<Output = Result<()>> + Send;
}Expand description
Methods that the IBus daemon provides for inputs methods to use
Required Methods
Sourcefn commit_text(
se: &SignalEmitter<'_>,
text: String,
) -> impl Future<Output = Result<()>> + Send
fn commit_text( se: &SignalEmitter<'_>, text: String, ) -> impl Future<Output = Result<()>> + Send
Type this text on behalf of the user
Sourcefn update_lookup_table(
se: &SignalEmitter<'_>,
table: &LookupTable,
visible: bool,
) -> impl Future<Output = Result<()>> + Send
fn update_lookup_table( se: &SignalEmitter<'_>, table: &LookupTable, visible: bool, ) -> impl Future<Output = Result<()>> + Send
(UI) Show of hide this lookup table
Sourcefn update_preedit_text(
se: &SignalEmitter<'_>,
text: String,
cursor_pos: u32,
visible: bool,
mode: IBusPreeditFocusMode,
) -> impl Future<Output = Result<()>> + Send
fn update_preedit_text( se: &SignalEmitter<'_>, text: String, cursor_pos: u32, visible: bool, mode: IBusPreeditFocusMode, ) -> impl Future<Output = Result<()>> + Send
(UI) Sets the preedit text.
The preedit text is a piece of text displayed in the place where text is to be written, but not written yet, in the sense that the underlying application is not aware of it.
cursor_pos is a value from 0 to text.len() indicating where the cursor should be
displayed.
Sourcefn update_auxiliary_text(
se: &SignalEmitter<'_>,
text: String,
visible: bool,
) -> impl Future<Output = Result<()>> + Send
fn update_auxiliary_text( se: &SignalEmitter<'_>, text: String, visible: bool, ) -> impl Future<Output = Result<()>> + Send
(UI) Sets the auxiliary text
The auxiliary text is a text shown in a floating textbox besides the place where text is to be written.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.